<?php

namespace Ems\portalGestor\Repository;

use Doctrine\ORM\EntityManager;

class EstruturaRepository
{
    protected $connection;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
    }

    public function getEstruturasGerenciaisResp($params) {
        $sql = <<<SQL
            SELECT EM.NRESTRUTURAM
              FROM ESTRUTURAM EM
              JOIN ESTRUTURAH EH ON EH.NRORG = EM.NRORG
                    AND EH.NRESTRUTURAM = EM.NRESTRUTURAM

                    /* BUSCA O HISTORICO MAIS RECENTE */
                    AND EH.DTMESCOMPETENC = (
                        SELECT MAX(DTMESCOMPETENC) 
                        FROM ESTRUTURAH EHH
                        WHERE EHH.NRORG = EH.NRORG 
                            AND EHH.NRESTRUTURAM = EH.NRESTRUTURAM
                            AND EHH.DTMESCOMPETENC <= SYSDATE
                        )

                    /* FILTRA POR ESTRUTURAS DIRETAMENTE GERENCIADAS PELO OPERADOR */
                    AND EH.NRPARCRESPINF = (
                        SELECT MAX(NRPARCNEGOCIO)
                        FROM OPERADOR OPER
                        WHERE OPER.NRORG = EM.NRORG
                            AND OPER.CDOPERADOR = :P_CDOPERADOR
                            AND OPER.IDATIVO = 'S'
                    )
            WHERE EM.NRORG = :P_NRORG
              AND EM.IDATIVO = 'S'
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $estruturas = $std->fetchAll();

        return $estruturas;
    }

    public function getEstruturasGerenciaisFilhas($params) {
        $sql = <<<SQL
            SELECT NRESTRUTURAMREL
            FROM HIERARQUIAORG HIER
            WHERE HIER.NRORG = :P_NRORG
              AND HIER.IDATIVO = 'S'
              AND HIER.NRESTRUTURAMSUP = :P_NRESTRUTURA
            GROUP BY NRESTRUTURAMREL
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $estruturas = $std->fetchAll();

        return $estruturas;
    }

    public function getNomeETipoEstrutura($params) {
        $sql = <<<SQL
            SELECT ('(' || TIPO.NMTIPOESTRUTURA || ') ' || ESTH.NMESTRUTURAH) NOME_TIPO_ESTRUTURA
            FROM ESTRUTURAH ESTH
              LEFT JOIN ESTRUTURAM ESTM
                 ON ESTH.NRESTRUTURAM = ESTM.NRESTRUTURAM
                AND ESTH.NRORG = ESTM.NRORG
              LEFT JOIN TIPOESTRUTURA TIPO
                 ON ESTM.NRTIPOESTRUTURA = TIPO.NRTIPOESTRUTURA
            WHERE ESTH.NRORG = :P_NRORG
              AND ESTH.IDATIVO = 'S'
              AND ESTH.NRESTRUTURAH = (
                    SELECT MAX(NRESTRUTURAH)
                    FROM ESTRUTURAH ESTH1
                    WHERE ESTH1.NRORG = :P_NRORG
                      AND ESTH1.IDATIVO = 'S'
                      AND ESTH1.NRESTRUTURAM = :P_NRESTRUTURA
              )
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $estruturas = $std->fetchAll();

        return $estruturas;
    }
}
